<?php
/**
 * Module: Widget Visibility
 *
 * @package automattic/jetpack
 */

/**
 * Module Name: Widget Visibility
 * Module Description: Control where widgets appear on your site.
 * First Introduced: 2.4
 * Requires Connection: No
 * Auto Activate: No
 * Sort Order: 17
 * Module Tags: Appearance
 * Feature: Appearance
 * Additional Search Queries: widget visibility, logic, conditional, widgets, widget
 */

require __DIR__ . '/widget-visibility/widget-conditions.php';
